@@ -56,6 +56,11 @@ object YarnUtils extends Logger {
     "kerberos".equalsIgnoreCase(yarnHttpAuth)
   }
 
+  lazy val hasYarnHttpSampleAuth: Boolean = {
+    val yarnHttpAuth: String = InternalConfigHolder.get[String](CommonConfig.STREAMPARK_YARN_AUTH)
+    "sample".equalsIgnoreCase(yarnHttpAuth)
+  }
+
   /**
    * @param appName
    * @return
@@ -123,9 +128,8 @@ object YarnUtils extends Logger {
    * @return
    *   </pre>
    */
-  def getRMWebAppURL(): String = {
-
-    if (rmHttpURL == null) {
+  def getRMWebAppURL(getLatest: Boolean = false): String = {
+    if (rmHttpURL == null || getLatest) {
       synchronized {
         val conf = HadoopUtils.hadoopConf
         val useHttps = YarnConfiguration.useHttps(conf)
@@ -256,15 +260,15 @@ object YarnUtils extends Logger {
   def restRequest(url: String): String = {
     if (url == null) return null
 
-    def request(url: String): String = {
-      logDebug("request url is " + url);
+    def request(reqUrl: String): String = {
+      logDebug("request url is " + reqUrl)
       val config = RequestConfig.custom.setConnectTimeout(5000).build
       if (hasYarnHttpKerberosAuth) {
         HadoopUtils
           .getUgi()
           .doAs(new PrivilegedExceptionAction[String] {
             override def run(): String = {
-              Try(HttpClientUtils.httpAuthGetRequest(url, config)) match {
+              Try(HttpClientUtils.httpAuthGetRequest(reqUrl, config)) match {
                 case Success(v) => v
                 case Failure(e) =>
                   logError("yarnUtils authRestRequest error, detail: ", e)
@@ -273,6 +277,9 @@ object YarnUtils extends Logger {
             }
           })
       } else {
+        val url = if (hasYarnHttpSampleAuth) {
+          s"$reqUrl?user.name=${HadoopUtils.hadoopUserName}"
+        } else reqUrl
         Try(HttpClientUtils.httpGetRequest(url, config)) match {
           case Success(v) => v
           case Failure(e) =>
@@ -282,9 +289,14 @@ object YarnUtils extends Logger {
       }
     }
 
-    if (url.startsWith("http://") || url.startsWith("https://")) request(url)
-    else {
-      request(s"${getRMWebAppURL()}/$url")
+    url match {
+      case u if u.matches("^http(|s)://.*") => request(url)
+      case _ =>
+        val resp = request(s"${getRMWebAppURL()}/$url")
+        if (resp != null) resp;
+        else {
+          request(s"${getRMWebAppURL(true)}/$url")
+        }
     }
   }
 
