@@ -31,7 +31,7 @@ create table `t_app_backup` (
   `sql_id` bigint default null,
   `config_id` bigint default null,
   `version` int default null,
-  `path` varchar(255) collate utf8mb4_general_ci default null,
+  `path` varchar(128) collate utf8mb4_general_ci default null,
   `description` varchar(255) collate utf8mb4_general_ci default null,
   `create_time` datetime not null default current_timestamp comment 'create time',
   primary key (`id`) using btree
@@ -47,7 +47,7 @@ create table `t_flink_app` (
   `job_type` tinyint default null,
   `execution_mode` tinyint default null,
   `resource_from` tinyint default null,
-  `project_id` varchar(64) collate utf8mb4_general_ci default null,
+  `project_id` bigint default null,
   `job_name` varchar(255) collate utf8mb4_general_ci default null,
   `module` varchar(255) collate utf8mb4_general_ci default null,
   `jar` varchar(255) collate utf8mb4_general_ci default null,
@@ -57,16 +57,16 @@ create table `t_flink_app` (
   `options` text collate utf8mb4_general_ci,
   `hot_params` text collate utf8mb4_general_ci,
   `user_id` bigint default null,
-  `app_id` varchar(255) collate utf8mb4_general_ci default null,
+  `app_id` varchar(64) collate utf8mb4_general_ci default null,
   `app_type` tinyint default null,
   `duration` bigint default null,
   `job_id` varchar(64) collate utf8mb4_general_ci default null,
   `job_manager_url` varchar(255) collate utf8mb4_general_ci default null,
   `version_id` bigint default null,
-  `cluster_id` varchar(255) collate utf8mb4_general_ci default null,
-  `k8s_namespace` varchar(255) collate utf8mb4_general_ci default null,
-  `flink_image` varchar(255) collate utf8mb4_general_ci default null,
-  `state` varchar(50) collate utf8mb4_general_ci default null,
+  `cluster_id` varchar(45) collate utf8mb4_general_ci default null,
+  `k8s_namespace` varchar(63) collate utf8mb4_general_ci default null,
+  `flink_image` varchar(128) collate utf8mb4_general_ci default null,
+  `state` int default null,
   `restart_size` int default null,
   `restart_count` int default null,
   `cp_threshold` int default null,
@@ -88,7 +88,7 @@ create table `t_flink_app` (
   `create_time` datetime not null default current_timestamp comment 'create time',
   `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
   `option_time` datetime default null,
-  `launch` tinyint default 1,
+  `release` tinyint default 1,
   `build` tinyint default 1,
   `start_time` datetime default null,
   `end_time` datetime default null,
@@ -102,7 +102,6 @@ create table `t_flink_app` (
   `default_mode_ingress` text collate utf8mb4_general_ci,
   `tags` varchar(500) default null,
   primary key (`id`) using btree,
-  key `inx_state` (`state`) using btree,
   key `inx_job_type` (`job_type`) using btree,
   key `inx_track` (`tracking`) using btree,
   index `inx_team` (`team_id`) using btree
@@ -148,8 +147,8 @@ create table `t_flink_env` (
   `id` bigint not null auto_increment comment 'id',
   `flink_name` varchar(128) collate utf8mb4_general_ci not null comment 'flink instance name',
   `flink_home` varchar(255) collate utf8mb4_general_ci not null comment 'flink home path',
-  `version` varchar(50) collate utf8mb4_general_ci not null comment 'flink version',
-  `scala_version` varchar(50) collate utf8mb4_general_ci not null comment 'scala version of flink',
+  `version` varchar(64) collate utf8mb4_general_ci not null comment 'flink version',
+  `scala_version` varchar(64) collate utf8mb4_general_ci not null comment 'scala version of flink',
   `flink_conf` text collate utf8mb4_general_ci not null comment 'flink-conf',
   `is_default` tinyint not null default 0 comment 'whether default version or not',
   `description` varchar(255) collate utf8mb4_general_ci default null comment 'description',
@@ -166,11 +165,12 @@ drop table if exists `t_flink_log`;
 create table `t_flink_log` (
   `id` bigint not null auto_increment,
   `app_id` bigint default null,
-  `yarn_app_id` varchar(50) collate utf8mb4_general_ci default null,
+  `yarn_app_id` varchar(64) collate utf8mb4_general_ci default null,
   `job_manager_url` varchar(255) collate utf8mb4_general_ci default null,
   `success` tinyint default null,
   `exception` text collate utf8mb4_general_ci,
   `option_time` datetime default null,
+  `option_name` tinyint default null,
   primary key (`id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -184,11 +184,11 @@ create table `t_flink_project` (
   `team_id` bigint not null,
   `name` varchar(255) collate utf8mb4_general_ci default null,
   `git_credential` tinyint not null,
-  `url` varchar(1000) collate utf8mb4_general_ci default null,
-  `branches` varchar(1000) collate utf8mb4_general_ci default null,
-  `user_name` varchar(255) collate utf8mb4_general_ci default null,
-  `password` varchar(255) collate utf8mb4_general_ci default null,
-  `prvkey_path` varchar(255) collate utf8mb4_general_ci default null,
+  `url` varchar(255) collate utf8mb4_general_ci default null,
+  `branches` varchar(64) collate utf8mb4_general_ci default null,
+  `user_name` varchar(64) collate utf8mb4_general_ci default null,
+  `password` varchar(64) collate utf8mb4_general_ci default null,
+  `prvkey_path` varchar(128) collate utf8mb4_general_ci default null,
   `pom` varchar(255) collate utf8mb4_general_ci default null,
   `build_args` varchar(255) default null,
   `type` tinyint default null,
@@ -236,20 +236,6 @@ create table `t_flink_sql` (
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
 
--- ----------------------------
--- Table structure for t_flink_tutorial
--- ----------------------------
-drop table if exists `t_flink_tutorial`;
-create table `t_flink_tutorial` (
-  `id` int not null auto_increment,
-  `type` tinyint default null,
-  `name` varchar(255) collate utf8mb4_general_ci default null,
-  `content` text collate utf8mb4_general_ci,
-  `create_time` datetime not null default current_timestamp comment 'create time',
-  primary key (`id`) using btree
-) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
-
-
 -- ----------------------------
 -- Table structure for t_menu
 -- ----------------------------
@@ -257,11 +243,11 @@ drop table if exists `t_menu`;
 create table `t_menu` (
   `menu_id` bigint not null auto_increment comment 'menu/button id',
   `parent_id` bigint not null comment 'parent menu id',
-  `menu_name` varchar(50) collate utf8mb4_general_ci not null comment 'menu button name',
-  `path` varchar(255) collate utf8mb4_general_ci default null comment 'routing path',
-  `component` varchar(255) collate utf8mb4_general_ci default null comment 'routing component component',
-  `perms` varchar(50) collate utf8mb4_general_ci default null comment 'authority id',
-  `icon` varchar(50) collate utf8mb4_general_ci default null comment 'icon',
+  `menu_name` varchar(64) collate utf8mb4_general_ci not null comment 'menu button name',
+  `path` varchar(64) collate utf8mb4_general_ci default null comment 'routing path',
+  `component` varchar(64) collate utf8mb4_general_ci default null comment 'routing component component',
+  `perms` varchar(64) collate utf8mb4_general_ci default null comment 'authority id',
+  `icon` varchar(64) collate utf8mb4_general_ci default null comment 'icon',
   `type` char(2) collate utf8mb4_general_ci default null comment 'type 0:menu 1:button',
   `display` tinyint collate utf8mb4_general_ci not null default 1 comment 'whether the menu is displayed',
   `order_num` int default null comment 'sort',
@@ -295,7 +281,7 @@ create table `t_message` (
 drop table if exists `t_team`;
 create table `t_team` (
   `id` bigint not null auto_increment comment 'team id',
-  `team_name` varchar(50) collate utf8mb4_general_ci not null comment 'team name',
+  `team_name` varchar(64) collate utf8mb4_general_ci not null comment 'team name',
   `description` varchar(255) collate utf8mb4_general_ci default null,
   `create_time` datetime not null default current_timestamp comment 'create time',
   `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
@@ -309,7 +295,7 @@ create table `t_team` (
 drop table if exists `t_variable`;
 create table `t_variable` (
   `id` bigint not null auto_increment,
-  `variable_code` varchar(100) collate utf8mb4_general_ci not null comment 'Variable code is used for parameter names passed to the program or as placeholders',
+  `variable_code` varchar(128) collate utf8mb4_general_ci not null comment 'Variable code is used for parameter names passed to the program or as placeholders',
   `variable_value` text collate utf8mb4_general_ci not null comment 'The specific value corresponding to the variable',
   `description` text collate utf8mb4_general_ci default null comment 'More detailed description of variables',
   `creator_id` bigint collate utf8mb4_general_ci not null comment 'user id of creator',
@@ -327,11 +313,10 @@ create table `t_variable` (
 drop table if exists `t_role`;
 create table `t_role` (
   `role_id` bigint not null auto_increment comment 'user id',
-  `role_name` varchar(50) collate utf8mb4_general_ci not null comment 'user name',
-  `remark` varchar(100) collate utf8mb4_general_ci default null comment 'remark',
+  `role_name` varchar(64) collate utf8mb4_general_ci not null comment 'role name',
   `create_time` datetime not null default current_timestamp comment 'create time',
   `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
-  `role_code` varchar(255) collate utf8mb4_general_ci default null comment 'role code',
+  `description` varchar(255) collate utf8mb4_general_ci default null comment 'description',
   primary key (`role_id`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
 
@@ -355,7 +340,7 @@ create table `t_role_menu` (
 drop table if exists `t_setting`;
 create table `t_setting` (
   `order_num` int default null,
-  `setting_key` varchar(50) collate utf8mb4_general_ci not null,
+  `setting_key` varchar(64) collate utf8mb4_general_ci not null,
   `setting_value` text collate utf8mb4_general_ci default null,
   `setting_name` varchar(255) collate utf8mb4_general_ci default null,
   `description` varchar(255) collate utf8mb4_general_ci default null,
@@ -370,20 +355,21 @@ create table `t_setting` (
 drop table if exists `t_user`;
 create table `t_user` (
   `user_id` bigint not null auto_increment comment 'user id',
-  `username` varchar(255) collate utf8mb4_general_ci not null comment 'user name',
-  `nick_name` varchar(50) collate utf8mb4_general_ci not null comment 'nick name',
-  `salt` varchar(255) collate utf8mb4_general_ci default null comment 'salt',
-  `password` varchar(128) collate utf8mb4_general_ci not null comment 'password',
-  `email` varchar(128) collate utf8mb4_general_ci default null comment 'email',
+  `username` varchar(64) collate utf8mb4_general_ci not null comment 'user name',
+  `nick_name` varchar(64) collate utf8mb4_general_ci not null comment 'nick name',
+  `salt` varchar(26) collate utf8mb4_general_ci default null comment 'salt',
+  `password` varchar(64) collate utf8mb4_general_ci not null comment 'password',
+  `email` varchar(64) collate utf8mb4_general_ci default null comment 'email',
   `user_type` int  not null comment 'user type 1:admin 2:user',
+  `login_type` tinyint default 0 comment 'login type 0:password 1:ldap',
   `last_team_id` bigint default null comment 'last team id',
   `status` char(1) collate utf8mb4_general_ci not null comment 'status 0:locked 1:active',
   `create_time` datetime not null default current_timestamp comment 'create time',
   `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
   `last_login_time` datetime default null comment 'last login time',
   `sex` char(1) collate utf8mb4_general_ci default null comment 'gender 0:male 1:female 2:confidential',
-  `avatar` varchar(100) collate utf8mb4_general_ci default null comment 'avatar',
-  `description` varchar(100) collate utf8mb4_general_ci default null comment 'description',
+  `avatar` varchar(128) collate utf8mb4_general_ci default null comment 'avatar',
+  `description` varchar(255) collate utf8mb4_general_ci default null comment 'description',
   primary key (`user_id`) using btree,
   unique key `un_username` (`username`) using btree
 ) engine=innodb auto_increment=100000 default charset=utf8mb4 collate=utf8mb4_general_ci;
@@ -430,18 +416,18 @@ create table `t_app_build_pipe`(
 drop table if exists `t_flink_cluster`;
 create table `t_flink_cluster` (
   `id` bigint not null auto_increment,
-  `address` varchar(255) default null comment 'url address of jobmanager',
-  `cluster_id` varchar(255) default null comment 'clusterid of session mode(yarn-session:application-id,k8s-session:cluster-id)',
-  `cluster_name` varchar(255) not null comment 'cluster name',
+  `address` varchar(150) default null comment 'url address of jobmanager',
+  `cluster_id` varchar(45) default null comment 'clusterid of session mode(yarn-session:application-id,k8s-session:cluster-id)',
+  `cluster_name` varchar(128) not null comment 'cluster name',
   `options` text comment 'json form of parameter collection ',
-  `yarn_queue` varchar(100) default null comment 'the yarn queue where the task is located',
+  `yarn_queue` varchar(128) default null comment 'the yarn queue where the task is located',
   `execution_mode` tinyint not null default 1 comment 'k8s execution session mode(1:remote,3:yarn-session,5:kubernetes-session)',
   `version_id` bigint not null comment 'flink version id',
-  `k8s_namespace` varchar(255) default 'default' comment 'k8s namespace',
-  `service_account` varchar(50) default null comment 'k8s service account',
+  `k8s_namespace` varchar(63) default 'default' comment 'k8s namespace',
+  `service_account` varchar(64) default null comment 'k8s service account',
   `description` varchar(255) default null,
   `user_id` bigint default null,
-  `flink_image` varchar(255) default null comment 'flink image',
+  `flink_image` varchar(128) default null comment 'flink image',
   `dynamic_properties` text comment 'allows specifying multiple generic configuration options',
   `k8s_rest_exposed_type` tinyint default 2 comment 'k8s export(0:loadbalancer,1:clusterip,2:nodeport)',
   `k8s_hadoop_integration` tinyint default 0,
@@ -464,7 +450,7 @@ create table `t_access_token` (
   `user_id` bigint,
   `token` varchar(1024) character set utf8mb4 collate utf8mb4_general_ci default null comment 'token',
   `expire_time` datetime default null comment 'expiration',
-  `description` varchar(512) character set utf8mb4 collate utf8mb4_general_ci default null comment 'description',
+  `description` varchar(255) character set utf8mb4 collate utf8mb4_general_ci default null comment 'description',
   `status` tinyint default null comment '1:enable,0:disable',
   `create_time` datetime not null default current_timestamp comment 'create time',
   `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
@@ -492,5 +478,32 @@ create table `t_alert_config` (
   index `inx_alert_user` (`user_id`) using btree
 ) engine = innodb default charset = utf8mb4 collate = utf8mb4_general_ci;
 
+-- ----------------------------
+-- Table of t_external_link
+-- ----------------------------
+drop table if exists `t_external_link`;
+CREATE TABLE `t_external_link` (
+  `id` bigint not null auto_increment primary key,
+  `badge_label` varchar(64) collate utf8mb4_general_ci default null,
+  `badge_name` varchar(64) collate utf8mb4_general_ci default null,
+  `badge_color` varchar(64) collate utf8mb4_general_ci default null,
+  `link_url` varchar(255) collate utf8mb4_general_ci default null,
+  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'create time',
+  `modify_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT 'modify time'
+) engine = innodb default charset=utf8mb4 collate=utf8mb4_general_ci;
+
+-- ----------------------------
+-- table structure for t_yarn_queue
+-- ----------------------------
+drop table if exists `t_yarn_queue`;
+create table `t_yarn_queue` (
+  `id` bigint not null primary key auto_increment comment 'queue id',
+  `team_id` bigint not null comment 'team id',
+  `queue_label` varchar(128) collate utf8mb4_general_ci not null comment 'queue label expression',
+  `description` varchar(255) collate utf8mb4_general_ci default null comment 'description of the queue label',
+  `create_time` datetime not null default current_timestamp comment 'create time',
+  `modify_time` datetime not null default current_timestamp on update current_timestamp comment 'modify time',
+   unique key `unq_team_id_queue_label` (`team_id`, `queue_label`) using btree
+) engine = innodb default charset = utf8mb4 collate = utf8mb4_general_ci;
 
 set foreign_key_checks = 1;
