@@ -205,7 +205,7 @@ class AlertServiceTest {
       duration = application.getEndTime().getTime() - application.getStartTime().getTime();
     }
     String format = "%s/proxy/%s/";
-    String url = String.format(format, YarnUtils.getRMWebAppURL(), application.getAppId());
+    String url = String.format(format, YarnUtils.getRMWebAppURL(false), application.getAppId());
 
     AlertTemplate template = new AlertTemplate();
     template.setJobName(application.getJobName());
