@@ -22,7 +22,7 @@ import {
   AppStateEnum,
   ConfigTypeEnum,
   ExecModeEnum,
-  LaunchStateEnum,
+  ReleaseStateEnum,
   OptionStateEnum,
   PipelineStepEnum,
 } from '/@/enums/flinkEnum';
@@ -144,24 +144,24 @@ export function handleIsStart(app: Recordable, optionApps: Recordable) {
   /**
    * Deployment failed FAILED(-1),
    * Done DONE(0),
-   * After the task is modified, NEED_LAUNCH(1) needs to be reissued,
-   * Online LAUNCHING(2),
+   * After the task is modified, NEED_RELEASE(1) needs to be reissued,
+   * Online releasing(2),
    * After going online, you need to restart NEED_RESTART(3),
    * Need to rollback NEED_ROLLBACK(4),
    * When the project changes, the task needs to be checked (whether the jar needs to be re-selected) NEED_CHECK(5),
    * The posted task has been revoked REVOKED(10);
    */
 
-  const launch = [LaunchStateEnum.DONE, LaunchStateEnum.NEED_RESTART].includes(app.launch);
+  const release = [ReleaseStateEnum.DONE, ReleaseStateEnum.NEED_RESTART].includes(app.release);
 
   const optionState =
     !optionApps.starting.get(app.id) || app['optionState'] === OptionStateEnum.NONE || false;
 
-  return status && launch && optionState;
+  return status && release && optionState;
 }
 
 export function handleYarnQueue(values: Recordable) {
-  if (values.executionMode == ExecModeEnum.YARN_APPLICATION) {
+  if (values.executionMode == ExecModeEnum.YARN_APPLICATION || values.executionMode == ExecModeEnum.YARN_PER_JOB) {
     const queue = values['yarnQueue'];
     if (queue != null && queue !== '' && queue !== undefined) {
       return queue;
@@ -224,13 +224,18 @@ export function handleDependencyJsonToPom(json, pomMap, jarMap) {
         const groupId = x.groupId;
         const artifactId = x.artifactId;
         const version = x.version;
+        const classifier = x.classifier;
         const exclusions = x.exclusions || [];
 
-        const id = groupId + '_' + artifactId;
+        const id =
+          classifier != null
+            ? groupId + '_' + artifactId + '_' + classifier
+            : groupId + '_' + artifactId;
         const mvnPom = {
           groupId: groupId,
           artifactId: artifactId,
           version: version,
+          classifier: classifier,
           exclusions: [] as any[],
         };
         if (exclusions != null && exclusions.length > 0) {
