@@ -17,15 +17,16 @@
 
 package org.apache.streampark.flink.client.bean
 
-import java.util.{Map => JavaMap}
-import javax.annotation.Nullable
-
 import org.apache.streampark.common.conf.FlinkVersion
 import org.apache.streampark.common.enums.ExecutionMode
 
+import javax.annotation.Nullable
+
+import java.util.{Map => JavaMap}
+
 case class ShutDownRequest(
     flinkVersion: FlinkVersion,
     executionMode: ExecutionMode,
+    @Nullable properties: JavaMap[String, Any],
     clusterId: String,
-    @Nullable kubernetesDeployParam: KubernetesDeployParam,
-    @Nullable properties: JavaMap[String, Any])
+    @Nullable kubernetesDeployParam: KubernetesDeployParam)
