@@ -21,7 +21,7 @@ import org.apache.streampark.flink.kubernetes.enums.FlinkJobState
 import org.apache.streampark.flink.kubernetes.model.TrackId
 
 /**
- * Notification of expecting changes to flink job state cache
- * held internally by K8sFlinkMonitor.
+ * Notification of expecting changes to flink job state cache held internally by K8sFlinkMonitor.
  */
-case class FlinkJobStateEvent(trackId: TrackId, jobState: FlinkJobState.Value, pollTime: Long) extends BuildInEvent
+case class FlinkJobStateEvent(trackId: TrackId, jobState: FlinkJobState.Value, pollTime: Long)
+  extends BuildInEvent
