@@ -20,7 +20,8 @@ import org.apache.streampark.common.conf.ConfigConst.printLogo
 
 import org.apache.flink.api.common.JobExecutionResult
 import org.apache.flink.api.java.utils.ParameterTool
-import org.apache.flink.table.api.{Table, TableDescriptor, TableEnvironment}
+import org.apache.flink.table.api.{Table, TableEnvironment}
+import org.apache.flink.table.descriptors.{ConnectorDescriptor, ConnectTableDescriptor}
 import org.apache.flink.table.module.ModuleEntry
 import org.apache.flink.table.sources.TableSource
 
@@ -39,31 +40,17 @@ class TableContext(override val parameter: ParameterTool, private val tableEnv:
    *
    * @param args
    */
-  def this(args: TableEnvConfig) = {
-    this(FlinkTableInitializer.initialize(args))
-  }
+  def this(args: TableEnvConfig) = this(FlinkTableInitializer.initialize(args))
 
   override def useModules(strings: String*): Unit = tableEnv.useModules(strings: _*)
 
   override def listFullModules(): Array[ModuleEntry] = tableEnv.listFullModules()
 
-  /**
-   * flink 1.14, need to implement
-   *
-   * @param path
-   * @param descriptor
-   */
-  def createTable(path: String, descriptor: TableDescriptor): Unit = {
-    tableEnv.createTable(path, descriptor)
-  }
+  @deprecated override def connect(
+      connectorDescriptor: ConnectorDescriptor): ConnectTableDescriptor =
+    tableEnv.connect(connectorDescriptor)
 
-  def createTemporaryTable(path: String, descriptor: TableDescriptor): Unit = {
-    tableEnv.createTemporaryTable(path, descriptor)
-  }
-
-  def from(descriptor: TableDescriptor): Table = tableEnv.from(descriptor)
-
-  @deprecated override def execute(jobName: String): JobExecutionResult = {
+  override def execute(jobName: String): JobExecutionResult = {
     printLogo(s"FlinkTable $jobName Starting...")
     tableEnv.execute(jobName)
   }
